==> haskell-bsb-http-chunked-0.0.0.4-427-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bsb-http-chunked
version:              0.0.0.4
visibility:           public
id:                   bsb-http-chunked-0.0.0.4-8pQS1PH4vHBnzwl7M5wdf
key:                  bsb-http-chunked-0.0.0.4-8pQS1PH4vHBnzwl7M5wdf
license:              BSD-3-Clause
copyright:
    (c) 2010-2014 Simon Meier
    (c) 2010 Jasper Van der Jeugt
    (c) 2013-2015 Leon P Smith
    (c) 2018 Simon Jakobi

maintainer:           Simon Jakobi <simon.jakobi@gmail.com>
author:
    Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi

stability:            Provisional
homepage:             http://github.com/sjakobi/bsb-http-chunked
synopsis:             Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).

    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.

category:             Data, Network
abi:                  a9a699d53a5783e5da66f314811703a8
exposed:              True
exposed-modules:      Data.ByteString.Builder.HTTP.Chunked
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bsb-http-chunked-0.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bsb-http-chunked-0.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bsb-http-chunked-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bsb-http-chunked
hs-libraries:         HSbsb-http-chunked-0.0.0.4-8pQS1PH4vHBnzwl7M5wdf
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:
    /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock

haddock-html:         /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bsb-http-chunked-0.0.0.4-428-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bsb-http-chunked
version:              0.0.0.4
visibility:           public
id:                   bsb-http-chunked-0.0.0.4-FYjUcVvSdHLEGMrgssr2Lh
key:                  bsb-http-chunked-0.0.0.4-FYjUcVvSdHLEGMrgssr2Lh
license:              BSD-3-Clause
copyright:
    (c) 2010-2014 Simon Meier
    (c) 2010 Jasper Van der Jeugt
    (c) 2013-2015 Leon P Smith
    (c) 2018 Simon Jakobi

maintainer:           Simon Jakobi <simon.jakobi@gmail.com>
author:
    Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi

stability:            Provisional
homepage:             http://github.com/sjakobi/bsb-http-chunked
synopsis:             Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).

    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.

category:             Data, Network
abi:                  6b8c60bcd633fbf876d219df3f7f25c5
exposed:              True
exposed-modules:      Data.ByteString.Builder.HTTP.Chunked
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bsb-http-chunked-0.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bsb-http-chunked-0.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bsb-http-chunked-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bsb-http-chunked
hs-libraries:         HSbsb-http-chunked-0.0.0.4-FYjUcVvSdHLEGMrgssr2Lh
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:
    /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock

haddock-html:         /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
